Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1601)

Unified Diff: content/renderer/dom_storage/local_storage_cached_area.h

Issue 1832813002: Add mojom module suffix in .mojom files in content. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address Tom's comment Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/dom_storage/local_storage_cached_area.h
diff --git a/content/renderer/dom_storage/local_storage_cached_area.h b/content/renderer/dom_storage/local_storage_cached_area.h
index ee6c0cd623018cb14128e1518390ee28e7283423..27977699e744fe2fc489f6b5f55dd1085195a12a 100644
--- a/content/renderer/dom_storage/local_storage_cached_area.h
+++ b/content/renderer/dom_storage/local_storage_cached_area.h
@@ -19,21 +19,26 @@ namespace content {
class DOMStorageMap;
class LocalStorageArea;
class LocalStorageCachedAreas;
+
+namespace mojom {
class StoragePartitionService;
+}
// An in-process implementation of LocalStorage using a LevelDB Mojo service.
// Maintains a complete cache of the origin's Map of key/value pairs for fast
// access. The cache is primed on first access and changes are written to the
// backend through the level db interface pointer. Mutations originating in
// other processes are applied to the cache via LevelDBObserver callbacks.
// There is one LocalStorageCachedArea for potentially many LocalStorageArea
// objects.
-class LocalStorageCachedArea : public LevelDBObserver,
+class LocalStorageCachedArea : public mojom::LevelDBObserver,
public base::RefCounted<LocalStorageCachedArea> {
public:
- LocalStorageCachedArea(const url::Origin& origin,
- StoragePartitionService* storage_partition_service,
- LocalStorageCachedAreas* cached_areas);
+ LocalStorageCachedArea(
+ const url::Origin& origin,
+ mojom::StoragePartitionService* storage_partition_service,
+ LocalStorageCachedAreas* cached_areas);
// These correspond to blink::WebStorageArea.
unsigned GetLength();
@@ -85,8 +90,8 @@ class LocalStorageCachedArea : public LevelDBObserver,
url::Origin origin_;
scoped_refptr<DOMStorageMap> map_;
std::map<base::string16, int> ignore_key_mutations_;
- LevelDBWrapperPtr leveldb_;
- mojo::Binding<LevelDBObserver> binding_;
+ mojom::LevelDBWrapperPtr leveldb_;
+ mojo::Binding<mojom::LevelDBObserver> binding_;
LocalStorageCachedAreas* cached_areas_;
std::map<std::string, LocalStorageArea*> areas_;
« no previous file with comments | « content/public/test/test_mojo_service.mojom ('k') | content/renderer/dom_storage/local_storage_cached_area.cc » ('j') | no next file with comments »
@@ -19,21 +19,26 @@ namespace content {
// access. The cache is primed on first access and changes are written to the
// backend through the level db interface pointer. Mutations originating in
-// other processes are applied to the cache via LevelDBObserver callbacks.
+// other processes are applied to the cache via mojom::LevelDBObserver
+// callbacks.
// There is one LocalStorageCachedArea for potentially many LocalStorageArea
// objects.

Powered by Google App Engine
This is Rietveld 408576698